@@ -33,10 +33,15 @@ extern zend_module_entry zip_module_entry;
 #define ZIP_OVERWRITE ZIP_TRUNCATE
 #endif
 
+/* since 1.10.1 */
+#ifndef ZIP_LENGTH_TO_END
+#define ZIP_LENGTH_TO_END 0
+#endif
+
 /* Additionnal flags not from libzip */
 #define ZIP_FL_OPEN_FILE_NOW (1u<<30)
 
-#define PHP_ZIP_VERSION "1.22.1"
+#define PHP_ZIP_VERSION "1.22.2"
 
 /* {{{ ZIP_OPENBASEDIR_CHECKPATH(filename) */
 #define ZIP_OPENBASEDIR_CHECKPATH(filename) \
